@@ -1,5 +1,5 @@
 package Proc::LoadMonitor;
-$Proc::LoadMonitor::VERSION = '0.002';
+$Proc::LoadMonitor::VERSION = '0.003';
 use Time::HiRes qw(tv_interval gettimeofday);
 use Moo;
 use strict;
@@ -69,6 +69,7 @@ sub report {
         total => tv_interval( $self->__start_time ),
         loops => $self->loops,
         jobs  => $self->jobs,
+        state => $self->state,
     };
 }
 
@@ -118,6 +119,7 @@ Proc::LoadMonitor - Load monitoring for worker processes
     #     load_05 => 0.650,     #  5 min. load avg. 
     #     load_10 => 0.510,     # 10 min. load avg. 
     #     load_15 => 0.414,     # 15 min. load avg.
+    #     state   => 'idle',    # 'busy'/'idle'
     #     total   => 110566.19  # total run time    
     # }
 
